@@ -33,7 +33,7 @@ define('GOLLEM_SORT_DESCEND', 1);
 /**
  * Gollem Base Class.
  *
- * $Horde: gollem/lib/Gollem.php,v 1.172 2005/08/15 05:36:51 slusarz Exp $
+ * $Horde: gollem/lib/Gollem.php,v 1.172.2.14 2005/12/02 00:36:37 jan Exp $
  *
  * See the enclosed file COPYING for license information (GPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
@@ -384,38 +384,53 @@ class Gollem {
      */
     function createFolder($dir, $name)
     {
+        $totalpath = Gollem::realPath($dir . '/' . $name);
+        if (!Gollem::verifyDir($totalpath)) {
+            return PEAR::raiseError(sprintf(_("Access denied to folder \"%s\"."), $totalpath));
+        }
+
         /* The $name parameter may contain additional directories so we
          * need to pass autocreatePath everything but the base filename. */
-        $totalpath = Gollem::realPath($dir . '/' . $name);
         $pos = strrpos($totalpath, '/');
         $dir = substr($totalpath, 0, $pos);
         $name = substr($totalpath, $pos + 1);
 
-        if (!Gollem::verifyDir($dir)) {
-            return PEAR::raiseError(sprintf(_("Access denied to folder \"%s\"."), $dir));
-        }
-
         /* Unfortunately, autocreatePath() is broken in VFS versions prior to
          * Horde 3.0.5.  We can work around this by simply clipping the root
          * '/' off the path. */
-        $autodir = (strpos($dir, '/') === 0) ? substr($dir, 1) : $dir;
+        require_once HORDE_BASE . '/lib/version.php';
+        if ((version_compare(HORDE_VERSION, '3.0.5') == -1) &&
+            (strpos($dir, '/') === 0)) {
+            $autodir = substr($dir, 1);
+        } else {
+            $autodir = $dir;
+        }
         $res = $GLOBALS['gollem_vfs']->autocreatePath($autodir);
         if (is_a($res, 'PEAR_Error')) {
             return $res;
         }
 
-        return $GLOBALS['gollem_vfs']->createFolder($dir, $name);
+        $res = $GLOBALS['gollem_vfs']->createFolder($dir, $name);
+        if (is_a($res, 'PEAR_Error')) {
+            return $res;
+        }
+
+        if (!empty($GLOBALS['gollem_be']['params']['permissions'])) {
+            $GLOBALS['gollem_vfs']->changePermissions($dir, $name, $GLOBALS['gollem_be']['params']['permissions']);
+        }
+
+        return true;
     }
 
     /**
      * Rename files using the current Gollem session settings.
      *
-     * @param string $oldDir  TODO
-     * @param string $old     TODO
-     * @param string $newDir  TODO
-     * @param string $old     TODO
+     * @param string $oldDir  Old directory name.
+     * @param string $old     Old file name.
+     * @param string $newDir  New directory name.
+     * @param string $old     New file name.
      *
-     * @return TODO
+     * @return mixed  True on success or a PEAR_Error object on failure.
      */
     function renameItem($oldDir, $old, $newDir, $new)
     {
@@ -425,10 +440,10 @@ class Gollem {
     /**
      * Delete a folder using the current Gollem session settings.
      *
-     * @param string $dir   TODO
-     * @param string $name  TODO
+     * @param string $dir   The subdirectory name.
+     * @param string $name  The folder name to delete.
      *
-     * @return TODO
+     * @return mixed  True on success or a PEAR_Error object on failure.
      */
     function deleteFolder($dir, $name)
     {
@@ -446,10 +461,10 @@ class Gollem {
     /**
      * Delete a file using the current Gollem session settings.
      *
-     * @param string $dir   TODO
-     * @param string $name  TODO
+     * @param string $dir   The directory name.
+     * @param string $name  The filename to delete.
      *
-     * @return TODO
+     * @return mixed  True on success or a PEAR_Error object on failure.
      */
     function deleteFile($dir, $name)
     {
@@ -462,11 +477,11 @@ class Gollem {
     /**
      * Change permissions on files using the current Gollem session settings.
      *
-     * @param string $dir          TODO
-     * @param string $name         TODO
-     * @param integer $permission  TODO
+     * @param string $dir         The directory name.
+     * @param string $name        The filename to change permissions on.
+     * @param string $permission  The permission mode to set.
      *
-     * @return TODO
+     * @return mixed  True on success or a PEAR_Error object on failure.
      */
     function changePermissions($dir, $name, $permission)
     {
@@ -479,16 +494,24 @@ class Gollem {
     /**
      * Write an uploaded file to the VFS backend.
      *
-     * @param string $dir       TODO
-     * @param string $name      TODO
-     * @param string $filename  TODO
+     * @param string $dir       The directory name.
+     * @param string $name      The filename to create.
+     * @param string $filename  The local file containing the file data.
      *
-     * @return TODO
+     * @return mixed  True on success or a PEAR_Error object on failure.
      */
     function writeFile($dir, $name, $filename)
     {
-        return $GLOBALS['gollem_vfs']->write($dir, $name, $filename);
+        $res = $GLOBALS['gollem_vfs']->write($dir, $name, $filename);
+        if (is_a($res, 'PEAR_Error')) {
+            return $res;
+        }
 
+        if (!empty($GLOBALS['gollem_be']['params']['permissions'])) {
+            $GLOBALS['gollem_vfs']->changePermissions($dir, $name, $GLOBALS['gollem_be']['params']['permissions']);
+        }
+
+        return true;
     }
 
     /**
@@ -590,6 +613,8 @@ class Gollem {
      */
     function getPreferredBackend()
     {
+        $backend_key = null;
+
         if (!empty($_SESSION['gollem']['backend_key'])) {
             $backend_key = $_SESSION['gollem']['backend_key'];
         } else {
@@ -616,6 +641,7 @@ class Gollem {
                     }
                 }
             }
+
         }
 
         return $backend_key;
@@ -636,12 +662,14 @@ class Gollem {
 
 
     /**
-     * TODO
+     * Parse the 'columns' preference.
+     *
+     * @return array  The list of columns to be displayed.
      */
-    function string2Columns($string)
+    function displayColumns()
     {
         $ret = array();
-        $lines = explode("\n", $string);
+        $lines = explode("\n", $GLOBALS['prefs']->getValue('columns'));
         foreach ($lines as $line) {
             $line = trim($line);
             if (!empty($line)) {
@@ -657,44 +685,27 @@ class Gollem {
     }
 
     /**
-     * TODO
-     */
-    function columns2String($hash)
-    {
-        foreach ($hash as $source => $columns) {
-            if (isset($string)) {
-                $string .= "\n";
-            } else {
-                $string = '';
-            }
-            $line = '';
-            foreach ($columns as $column) {
-                if (!empty($line)) {
-                    $line .= "\t";
-                }
-                $line .= $column;
-            }
-        }
-
-        return $string;
-    }
-
-    /**
-     * Checks if a user has the specified permissions on the current backend.
+     * Checks if a user has the specified permissions on the selected backend.
      *
      * @param string $filter       What are we checking for.
      * @param integer $permission  What permission to check for.
+     * @param string $backend      The backend to check.  If empty, check
+     *                             the current backend.
      *
      * @return boolean  Returns true if the user has permission, false if
      *                  they do not.
      */
-    function checkPermissions($filter, $permission = PERMS_READ)
+    function checkPermissions($filter, $permission = PERMS_READ,
+                              $backend = null)
     {
         $userID = Auth::getAuth();
+        if (is_null($backend)) {
+            $backend = $_SESSION['gollem']['backend_key'];
+        }
 
         switch ($filter) {
         case 'backend':
-            $backendTag = 'gollem:backends:' . $_SESSION['gollem']['backend_key'];
+            $backendTag = 'gollem:backends:' . $backend;
             if (!$GLOBALS['perms']->exists($backendTag) ||
                 $GLOBALS['perms']->hasPermission($backendTag, $userID, $permission)) {
                 return true;
@@ -705,32 +716,6 @@ class Gollem {
         return false;
     }
 
-    /**
-     * TODO
-     */
-    function permissionsFilter($backends, $filter, $permission = PERMS_READ)
-    {
-        $out = array();
-        $userID = Auth::getAuth();
-
-        switch ($filter) {
-        case 'backend':
-            foreach ($backends as $backendID => $name) {
-                $backendTag = 'gollem:backends:' . $backendID;
-                if (!$GLOBALS['perms']->exists($backendTag) ||
-                    $GLOBALS['perms']->hasPermission($backendTag, $userID, $permission)) {
-                    $out[$backendID] = $name;
-                }
-            }
-            break;
-
-        default:
-            $out = $backends;
-        }
-
-        return $out;
-    }
-
     /**
      * Produces a directory link used for navigation.
      *
@@ -750,7 +735,7 @@ class Gollem {
             $parts = explode('/', $currdir);
             $parts_count = count($parts);
 
-            $label[] = Horde::link(Util::addParameter($url, 'dir', $root_dir), sprintf(_("Up to %s"), _("Root")), 'header') . '[' . _("Root") . ']</a>';
+            $label[] = Horde::link(Util::addParameter($url, 'dir', $root_dir), sprintf(_("Up to %s"), _("Root"))) . '[' . _("Root") . ']</a>';
 
             for ($i = 1; $i <= $parts_count; $i++) {
                 $part = array_slice($parts, 0, $i);
@@ -760,7 +745,7 @@ class Gollem {
                     if ($i == $parts_count) {
                         $label[] = $parts[($i - 1)];
                     } else {
-                        $label[] = Horde::link(Util::addParameter($url, 'dir', $dir), sprintf(_("Up to %s"), $dir), 'header') . $parts[($i - 1)] . '</a>';
+                        $label[] = Horde::link(Util::addParameter($url, 'dir', $dir), sprintf(_("Up to %s"), $dir)) . $parts[($i - 1)] . '</a>';
                     }
                 }
             }
@@ -788,6 +773,22 @@ class Gollem {
             }
         }
 
+        if (!empty($_SESSION['gollem'])) {
+            if (Auth::isAdmin()) {
+                $menu->add(Util::addParameter(Horde::applicationUrl('permissions.php'), 'backend', $_SESSION['gollem']['backend_key']), _("Permissions"), 'administration.png', $GLOBALS['registry']->getImageDir('horde'));
+            }
+    
+            if ($_SESSION['gollem']['hasquota']) {
+                if ($GLOBALS['browser']->hasFeature('javascript')) {
+                    Horde::addScriptFile('open_quota_win.js', 'gollem');
+                    $quota_url = 'javascript:open_quota_win(\'' . addslashes('backend=' . $_SESSION['gollem']['backend_key']) . '\');';
+                } else {
+                    $quota_url = Util::addParameter(Horde::applicationUrl('quota.php'), 'backend', $_SESSION['gollem']['backend_key']);
+                }
+                $menu->add($quota_url, _("Check Quota"), 'info_icon.png', $GLOBALS['registry']->getImageDir('horde'));
+            }
+        }
+ 
         if ($returnType == 'object') {
             return $menu;
         } else {
@@ -824,7 +825,12 @@ class Gollem {
             $GLOBALS['gollem_backends'] = $_SESSION['gollem']['be_list'];
         } else {
             require GOLLEM_BASE . '/config/backends.php';
-            $GLOBALS['gollem_backends'] = Gollem::permissionsFilter($backends, 'backend', PERMS_SHOW);
+            $GLOBALS['gollem_backends'] = array();
+            foreach ($backends as $key => $val) {
+                if (Gollem::checkPermissions('backend', PERMS_SHOW, $key)) {
+                    $GLOBALS['gollem_backends'][$key] = $val;
+                }
+            }
         }
     }
 
@@ -901,11 +907,48 @@ class Gollem {
      */
     function &getVFSOb($backend_key)
     {
-        $params = $_SESSION['gollem']['backends'][$backend_key]['params'];
+        $be_config = &$_SESSION['gollem']['backends'][$backend_key];
+        $params = $be_config['params'];
         if (!empty($params['password'])) {
             $params['password'] = Secret::read(Secret::getKey('gollem'), $params['password']);
         }
-        $ob = &VFS::singleton($_SESSION['gollem']['backends'][$backend_key]['driver'], $params);
+        $ob = &VFS::singleton($be_config['driver'], $params);
+
+        if (!isset($be_config['quota_val'])) {
+            /* Only set quota information when we are finished with session
+             * initialization (a VFS object is created in
+             * MIMP_Session::createSession before all session variables -
+             * e.g. 'hasquota' - are set.) */
+            $sess_setup = isset($_SESSION['gollem']['hasquota']);
+            if ($sess_setup) {
+                $be_config['quota_val'] = -1;
+            }
+            if ((!$sess_setup || !empty($_SESSION['gollem']['hasquota'])) &&
+                !empty($be_config['quota'])) {
+                $quota_metric = array(
+                    'B' => VFS_QUOTA_METRIC_BYTE,
+                    'KB' => VFS_QUOTA_METRIC_KB,
+                    'MB' => VFS_QUOTA_METRIC_MB,
+                    'GB' => VFS_QUOTA_METRIC_GB
+                );
+                $quota_str = explode(' ', $be_config['quota'], 2);
+                if (is_numeric($quota_str[0])) {
+                    $metric = trim(strtoupper($quota_str[1]));
+                    if (!isset($quota_metric[$metric])) {
+                        $metric = 'B';
+                    }
+                    $ob->setQuota($quota_str[0], $quota_metric[$metric]);
+                    $ob->setQuotaRoot(Gollem::getRoot());
+                    if ($sess_setup) {
+                        $be_config['quota_val'] = $quota_str[0];
+                        $be_config['quota_metric'] = $quota_metric[$metric];
+                    }
+                }
+            }
+        } elseif ($be_config['quota_val'] > -1) {
+            $ob->setQuota($be_config['quota_val'], $be_config['quota_metric']);
+            $ob->setQuotaRoot(Gollem::getRoot());
+        }
 
         return $ob;
     }
@@ -928,4 +971,36 @@ class Gollem {
         return $path;
     }
 
+
+    /**
+     * Get a list of the available backends for permissions setup.
+     *
+     * @param string $perms  'all' - Return all backends.
+     *                       'perms' - Return backends which have perms set.
+     *                       'noperms' - Return backends which have no perms
+     *                                   set.
+     *
+     * @return array  The requested backend list.
+     */
+    function &getBackends($perms = 'all')
+    {
+        $backends = $_SESSION['gollem']['backends'];
+        $perms = strtolower($perms);
+
+        if ($perms != 'all') {
+            foreach (array_keys($backends) as $key) {
+                $exists = $GLOBALS['perms']->exists('gollem:backends:' . $key);
+                /* Don't list if the perms don't exist for this backend and we
+                 * want backends with perms only OR if the perms exist for
+                 * this backend and we only want backends which have none. */
+                if ((!$exists && ($perms == 'perms')) ||
+                    ($exists && ($perms == 'noperms'))) {
+                    unset($backends[$key]);
+                }
+            }
+        }
+
+        return $backends;
+    }
+
 }
