@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: gollem/manager.php,v 1.146.2.2 2005/08/15 11:42:28 jan Exp $
+ * $Horde: gollem/manager.php,v 1.146.2.8 2005/12/04 21:21:54 chuck Exp $
  *
  * Copyright 1999-2005 Charles J. Hagenbuch <chuck@horde.org>
  * Copyright 1999-2005 Max Kalika <max@horde.org>
@@ -208,12 +208,6 @@ if (is_a($list, 'PEAR_Error')) {
     }
 }
 
-$title = htmlspecialchars($GLOBALS['gollem_be']['label']);
-
-require GOLLEM_TEMPLATES . '/common-header.inc';
-require GOLLEM_TEMPLATES . '/menu.inc';
-require_once $registry->get('templates', 'horde') . '/contents/open_view_win.js';
-
 /* Image links. */
 $download_img = Horde::img('download.png', _("Download"), null, $registry->getImageDir('horde'));
 $folder_img = Horde::img('manager/folder.png', _("folder"));
@@ -231,10 +225,17 @@ foreach ($_SESSION['gollem']['clipboard'] as $val) {
     }
 }
 
+$title = $GLOBALS['gollem_be']['label'];
+require GOLLEM_TEMPLATES . '/common-header.inc';
+require GOLLEM_TEMPLATES . '/menu.inc';
+if ($browser->hasFeature('javascript')) {
+    require GOLLEM_TEMPLATES . '/manager/javascript.inc';
+    require $registry->get('templates', 'horde') . '/contents/open_view_win.js';
+}
 require GOLLEM_TEMPLATES . '/manager/header.inc';
 
 /* Read the columns to display from the preferences. */
-$sources = Gollem::string2Columns($prefs->getValue('columns'));
+$sources = Gollem::displayColumns();
 $columns = isset($sources[$backkey]) ? $sources[$backkey] : $GLOBALS['gollem_be']['attributes'];
 
 /* Set up column listing for cloop. */
@@ -324,7 +325,7 @@ if (is_array($list) &&
 
             // Try a view link.
             $url = Util::addParameter($view_url, array('actionID' => 'view_file', 'type' => $val['type'], 'file' => $val['name'], 'dir' => $currdir, 'driver' => $GLOBALS['gollem_be']['driver']));
-            $item['link'] = Horde::link('', '', '', '', "view('$url', '" . $val['name'] . "'); return false;") . $name . '</a>';
+            $item['link'] = Horde::link('#', '', '', '', "view('$url', '" . $val['name'] . "'); return false;") . $name . '</a>';
             break;
         }
 
